@@ -35,6 +35,19 @@ class Instrument:
 		if 'step' in parameters:
 			self.step = parameters["step"]
 
+	def add_rest(self, state):
+		if state["tick"] == 0:
+			if hasattr(self, "bar"):
+				self.track + self.bar
+			b = Bar()
+			b.set_meter(state["meter"])
+			b.key = state["key"]
+			self.bar = b
+
+		self.bar.place_notes(None, state["resolution"])
+		self.last_tick = (state["iterations"], state["tick"])
+
+
 	def play(self, state):
 
 		if not(self.midi_set) and 'midi_instr' in self.params:
@@ -64,8 +77,10 @@ class Instrument:
 			n = self.generate_note(state)
 			v = self.generate_velocity(state)
 			if n != None:
+				for note in n:
+					note.dynamics["velocity"] = v
 				# Record played notes in a Track
-				if self.last_tick:
+				if self.last_tick != (state["iterations"], state["tick"]):
 					self.bar.place_notes(n, state["resolution"])
 				else:
 					self.bar.bar[-1][2].add_notes(n)
