@@ -13,7 +13,11 @@ fietsen_intro = [
 	   (3, ["IV5", "bIII5"]),
 	   (4, ["I5", "bIII5"]),
 	   (7, ["IV5", "bIII5"]),
-	   (8, 'R')]
+	   (8, ["I5", "bIII5"]),
+	   (11, ["IV5", "bIII5"]),
+	   (12, ["I5", "bIII5"]),
+	   (15, ["IV5", "V7#9"]),
+	   (16, 'R')]
 
 fietsen_couplet = [(0, ["I", "IV", "#Vdom7", "V7"]),
 		   (1, 'R')]
